@@ -573,7 +573,7 @@ typedef __arch_dependant__ sph_s64;
  * @param x   the 32-bit value to byte-swap
  * @return  the byte-swapped value
  */
-static inline sph_u32 sph_bswap32(sph_u32 x);
+static __inline sph_u32 sph_bswap32(sph_u32 x);
 
 /**
  * Byte-swap a 64-bit word. This is an inline function which resorts
@@ -584,7 +584,7 @@ static inline sph_u32 sph_bswap32(sph_u32 x);
  * @param x   the 64-bit value to byte-swap
  * @return  the byte-swapped value
  */
-static inline sph_u64 sph_bswap64(sph_u64 x);
+static __inline sph_u64 sph_bswap64(sph_u64 x);
 
 /**
  * Decode a 16-bit unsigned value from memory, in little-endian convention
@@ -593,7 +593,7 @@ static inline sph_u64 sph_bswap64(sph_u64 x);
  * @param src   the source address
  * @return  the decoded value
  */
-static inline unsigned sph_dec16le(const void *src);
+static __inline unsigned sph_dec16le(const void *src);
 
 /**
  * Encode a 16-bit unsigned value into memory, in little-endian convention
@@ -602,7 +602,7 @@ static inline unsigned sph_dec16le(const void *src);
  * @param dst   the destination buffer
  * @param val   the value to encode
  */
-static inline void sph_enc16le(void *dst, unsigned val);
+static __inline void sph_enc16le(void *dst, unsigned val);
 
 /**
  * Decode a 16-bit unsigned value from memory, in big-endian convention
@@ -611,7 +611,7 @@ static inline void sph_enc16le(void *dst, unsigned val);
  * @param src   the source address
  * @return  the decoded value
  */
-static inline unsigned sph_dec16be(const void *src);
+static __inline unsigned sph_dec16be(const void *src);
 
 /**
  * Encode a 16-bit unsigned value into memory, in big-endian convention
@@ -620,7 +620,7 @@ static inline unsigned sph_dec16be(const void *src);
  * @param dst   the destination buffer
  * @param val   the value to encode
  */
-static inline void sph_enc16be(void *dst, unsigned val);
+static __inline void sph_enc16be(void *dst, unsigned val);
 
 /**
  * Decode a 32-bit unsigned value from memory, in little-endian convention
@@ -629,7 +629,7 @@ static inline void sph_enc16be(void *dst, unsigned val);
  * @param src   the source address
  * @return  the decoded value
  */
-static inline sph_u32 sph_dec32le(const void *src);
+static __inline sph_u32 sph_dec32le(const void *src);
 
 /**
  * Decode a 32-bit unsigned value from memory, in little-endian convention
@@ -641,7 +641,7 @@ static inline sph_u32 sph_dec32le(const void *src);
  * @param src   the source address
  * @return  the decoded value
  */
-static inline sph_u32 sph_dec32le_aligned(const void *src);
+static __inline sph_u32 sph_dec32le_aligned(const void *src);
 
 /**
  * Encode a 32-bit unsigned value into memory, in little-endian convention
@@ -650,7 +650,7 @@ static inline sph_u32 sph_dec32le_aligned(const void *src);
  * @param dst   the destination buffer
  * @param val   the value to encode
  */
-static inline void sph_enc32le(void *dst, sph_u32 val);
+static __inline void sph_enc32le(void *dst, sph_u32 val);
 
 /**
  * Encode a 32-bit unsigned value into memory, in little-endian convention
@@ -662,7 +662,7 @@ static inline void sph_enc32le(void *dst, sph_u32 val);
  * @param dst   the destination buffer
  * @param val   the value to encode
  */
-static inline void sph_enc32le_aligned(void *dst, sph_u32 val);
+static __inline void sph_enc32le_aligned(void *dst, sph_u32 val);
 
 /**
  * Decode a 32-bit unsigned value from memory, in big-endian convention
@@ -671,7 +671,7 @@ static inline void sph_enc32le_aligned(void *dst, sph_u32 val);
  * @param src   the source address
  * @return  the decoded value
  */
-static inline sph_u32 sph_dec32be(const void *src);
+static __inline sph_u32 sph_dec32be(const void *src);
 
 /**
  * Decode a 32-bit unsigned value from memory, in big-endian convention
@@ -683,7 +683,7 @@ static inline sph_u32 sph_dec32be(const void *src);
  * @param src   the source address
  * @return  the decoded value
  */
-static inline sph_u32 sph_dec32be_aligned(const void *src);
+static __inline sph_u32 sph_dec32be_aligned(const void *src);
 
 /**
  * Encode a 32-bit unsigned value into memory, in big-endian convention
@@ -692,7 +692,7 @@ static inline sph_u32 sph_dec32be_aligned(const void *src);
  * @param dst   the destination buffer
  * @param val   the value to encode
  */
-static inline void sph_enc32be(void *dst, sph_u32 val);
+static __inline void sph_enc32be(void *dst, sph_u32 val);
 
 /**
  * Encode a 32-bit unsigned value into memory, in big-endian convention
@@ -704,7 +704,7 @@ static inline void sph_enc32be(void *dst, sph_u32 val);
  * @param dst   the destination buffer
  * @param val   the value to encode
  */
-static inline void sph_enc32be_aligned(void *dst, sph_u32 val);
+static __inline void sph_enc32be_aligned(void *dst, sph_u32 val);
 
 /**
  * Decode a 64-bit unsigned value from memory, in little-endian convention
@@ -714,7 +714,7 @@ static inline void sph_enc32be_aligned(void *dst, sph_u32 val);
  * @param src   the source address
  * @return  the decoded value
  */
-static inline sph_u64 sph_dec64le(const void *src);
+static __inline sph_u64 sph_dec64le(const void *src);
 
 /**
  * Decode a 64-bit unsigned value from memory, in little-endian convention
@@ -727,7 +727,7 @@ static inline sph_u64 sph_dec64le(const void *src);
  * @param src   the source address
  * @return  the decoded value
  */
-static inline sph_u64 sph_dec64le_aligned(const void *src);
+static __inline sph_u64 sph_dec64le_aligned(const void *src);
 
 /**
  * Encode a 64-bit unsigned value into memory, in little-endian convention
@@ -737,7 +737,7 @@ static inline sph_u64 sph_dec64le_aligned(const void *src);
  * @param dst   the destination buffer
  * @param val   the value to encode
  */
-static inline void sph_enc64le(void *dst, sph_u64 val);
+static __inline void sph_enc64le(void *dst, sph_u64 val);
 
 /**
  * Encode a 64-bit unsigned value into memory, in little-endian convention
@@ -751,7 +751,7 @@ static inline void sph_enc64le(void *dst, sph_u64 val);
  * @param dst   the destination buffer
  * @param val   the value to encode
  */
-static inline void sph_enc64le_aligned(void *dst, sph_u64 val);
+static __inline void sph_enc64le_aligned(void *dst, sph_u64 val);
 
 /**
  * Decode a 64-bit unsigned value from memory, in big-endian convention
@@ -761,7 +761,7 @@ static inline void sph_enc64le_aligned(void *dst, sph_u64 val);
  * @param src   the source address
  * @return  the decoded value
  */
-static inline sph_u64 sph_dec64be(const void *src);
+static __inline sph_u64 sph_dec64be(const void *src);
 
 /**
  * Decode a 64-bit unsigned value from memory, in big-endian convention
@@ -774,7 +774,7 @@ static inline sph_u64 sph_dec64be(const void *src);
  * @param src   the source address
  * @return  the decoded value
  */
-static inline sph_u64 sph_dec64be_aligned(const void *src);
+static __inline sph_u64 sph_dec64be_aligned(const void *src);
 
 /**
  * Encode a 64-bit unsigned value into memory, in big-endian convention
@@ -784,7 +784,7 @@ static inline sph_u64 sph_dec64be_aligned(const void *src);
  * @param dst   the destination buffer
  * @param val   the value to encode
  */
-static inline void sph_enc64be(void *dst, sph_u64 val);
+static __inline void sph_enc64be(void *dst, sph_u64 val);
 
 /**
  * Encode a 64-bit unsigned value into memory, in big-endian convention
@@ -798,7 +798,7 @@ static inline void sph_enc64be(void *dst, sph_u64 val);
  * @param dst   the destination buffer
  * @param val   the value to encode
  */
-static inline void sph_enc64be_aligned(void *dst, sph_u64 val);
+static __inline void sph_enc64be_aligned(void *dst, sph_u64 val);
 
 #endif
 
